/*
 * Created 2018 by Max Fahl, PIXILAB Technologies AB.
 */

import { PropertyAccessor, Script, ScriptEnv } from 'system_lib/Script';
import { resource } from "../system_lib/Metadata";
import { SimpleFile } from "../system/SimpleFile";
import { WebRenderer } from "../system/WebRenderer";

// noinspection JSUnusedGlobalSymbols
export class Scribble extends Script {

	// private static STORAGE_FILE_NAME: string = 'PhotoStage.storage.json';
	private readonly kBlockPath = '/public/block/Scribble/ScribbleResult';
	private readonly kWebRendererFolderPath: string = '/public/WebRenderer';

	private mPublishedTask: PropertyAccessor<boolean>;

	public constructor(env: ScriptEnv) {
		super(env);
		this.mPublishedTask = this.getProperty('Realm.Scribble.group.Scribble.OnPublish.running', () => {});
		console.log('Scribble started.');
	}

	@resource()
	public finish(data: { tempPath: string }): any {
		const { tempPath } = data;
		const tempSrc = "/temp/" + tempPath;

		return new Promise((resolve) => {
			SimpleFile.copy(
				tempSrc,
				`${ this.kBlockPath }/media/scribble.png`,
				true
			).then(() => {
				SimpleFile.read(`${ this.kBlockPath }/Spec.pixi`).then(
					contents => {

						let data = JSON.parse(contents);
						data['root']['blocks'][0]['mMedia']['mFileTime'] = +(new Date());

						SimpleFile.write(
							`${ this.kBlockPath }/Spec.pixi`,
							JSON.stringify(data)
						).then(() => {
							this.mPublishedTask.value = true;

							this.saveResult();

							resolve();
						});
					}
				);
			});
		});
	}

	private saveResult(): void {
		let compositeBlockUrl = "http://localhost:9080/spot/index.ftl?wsConn=1&noConn=1&transparent=1&block=Main/ScribbleOverPhotoResult";
		let now = new Date();
		let filename = `${ now.getFullYear() }-${ this.padZero(now.getMonth()) }-${ this.padZero(now.getDate()) }-${ this.padZero(now.getHours()) }${ this.padZero(now.getMinutes()) }.png`;

		WebRenderer.render(
			compositeBlockUrl,
			'temp.png',
			1080,
			1920,
			2000,
			true
		).then(() => {
			SimpleFile.move(
				`${ this.kWebRendererFolderPath }/temp.png`,
				`/public/scribble-results/${ filename }`,
				true
			);
		});
	}

	private padZero(num: number): string {
		let numStr = num.toString();
		if (numStr.length === 1)
			return '0' + numStr;
		return numStr;
	}
}
